@@ -1,10 +1,10 @@
 # -*- encoding: utf-8; indent-tabs-mode: nil -*-
 #
 #     Acme::MetaSyntactic::soviet -- NATO codenames for Soviet-designed equipment
-#     Copyright (C) 2008, 2012, 2016 Jean Forget
+#     Copyright (C) 2008, 2012, 2016, 2021 Jean Forget
 #
 #     See the license in the embedded documentation below.
-# 
+#
 package Acme::MetaSyntactic::soviet;
 
 use warnings;
@@ -12,7 +12,7 @@ use strict;
 
 use Acme::MetaSyntactic::MultiList;
 our @ISA = qw( Acme::MetaSyntactic::MultiList );
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 my $data = { default => 'electronic' };
 my ($category2, $category3);
@@ -113,16 +113,17 @@ The default category is 'electronic'.
 
 =head1 VERSION
 
-This  is  version 0.05,  the  "Styx"  version,  released on  the  49th
-anniversary  of the  sinking of  the Israeli  destroyer Eilat  by Styx
-missiles fired from Egyptian patrol boats.
+This  is  version 0.06,  the  Fresco  version,  released on  the  49th
+anniversary  of the  dogfight between  a  MiG-17 Fresco  flown by  ace
+Colonel Tomb and a F-4 Phantom flown by soon-to-be-aces Cunningham and
+Driscoll
 
 =head1 SYNOPSIS
 
     use Acme::MetaSyntactic;
 
     my $meta = Acme::MetaSyntactic->new( 'soviet' );
-    
+
     print $meta->name();          # return a single name
     my @names = $meta->name( 4 ); # return 4 distinct names (if possible)
 
@@ -144,10 +145,11 @@ Jean Forget
 
 =head1 SOURCES
 
-Note: I  have used  only sources published  I<before> the fall  of the
-Soviet Union. Therefore, the  module name is C<A::MS::soviet>, with no
-"ex-"  prefix.  For  each entry,  the  sources are  listed, with  page
-numbers for the books. The games use data cards, which are unnumbered.
+Note: I  have used only  sources published  I<before> the fall  of the
+Soviet Union. Therefore, the module  name is C<A::MS::soviet>, with no
+"ex-"  prefix. For  each  entry,  the sources  are  listed, with  page
+numbers  for  most  books.  The   games  use  data  cards,  which  are
+unnumbered.
 
 Some sources, especially early  sources, may contain some errors. Some
 equipment  may appear with  faulty intelligence  reports which  give a
@@ -182,7 +184,8 @@ abbreviated as I<JWARH>.
 I<Air Superiority>
 designed by J.D. Webster
 and published by GDW in 1987
-(ISBN 0-943580-19-6)
+(ISBN 0-943580-19-6) see
+L<https://boardgamegeek.com/boardgame/3613/air-superiority>
 abbreviated as I<ASu>.
 
 =item *
@@ -190,7 +193,8 @@ abbreviated as I<ASu>.
 I<Air Strike>
 designed by J.D. Webster
 and published by GDW in 1987
-(ISBN 0-943580-30-7)
+(ISBN 0-943580-30-7), see
+L<https://boardgamegeek.com/boardgameexpansion/3614/air-strike>
 abbreviated as I<ASt>.
 
 =item *
@@ -198,7 +202,8 @@ abbreviated as I<ASt>.
 I<Desert Falcons>
 designed by J.D. Webster
 and published by GDW in 1988
-(ISBN 0-943580-97-8)
+(ISBN 0-943580-97-8), see
+L<https://boardgamegeek.com/boardgame/8474/desert-falcons>
 abbreviated as I<DF>.
 
 =item *
@@ -234,7 +239,8 @@ abbreviated as I<AWA>.
 I<Air War>
 designed by David Isby
 published in 1977 by SPI and then in 1983 by TSR
-(no ISBN)
+(no ISBN), see
+L<https://boardgamegeek.com/boardgame/1629/air-war-modern-tactical-air-combat>
 abbreviated as I<SPIAW>.
 
 =item *
@@ -245,6 +251,21 @@ published by Quill in 1988
 (ISBN 0-668-07979-2)
 abbreviated as I<HTMW>.
 
+=item *
+
+I<Science et Vie> special issue I<Aviation 77>
+published by Excelsior Publications SA in May 1977
+abbreviated as I<S&V>.
+
+=item *
+
+I<Aircraft Armament>
+(or I<The Illustrated Encyclopedia of Aircraft Armament>)
+written by Bill Gunston
+published by Salamande Books Ltd. in 1987
+(ISBN 0-86101-314-X)
+abbreviated as I<IEAA>.
+
 =back
 
 =head2 Minor Sources
@@ -259,7 +280,8 @@ without trying to give an exhaustive list of some category or other.
 I<Rolling Thunder>
 designed by Steve Weiss
 published by Group Three Games in 1985
-(no ISBN)
+(no ISBN), see
+L<https://boardgamegeek.com/boardgame/6228/rolling-thunder>
 abbreviated as I<RT>.
 
 =item *
@@ -288,6 +310,29 @@ published by Berkley International Edition in 1987
 ISBN 0-425-10242-4
 abbreviated as I<RSR>.
 
+=item *
+
+I<Helicopter Aces>
+by James W Bradin,
+published by Avon Books in 1990,
+ISBN 0-380-75847-4,
+abbreviated as I<HA>.
+
+=item *
+
+I<Bullseye One Reactor> written by  Dan McKinnon published by House of
+Hits  Publishing  in 1987  and  by  Airlife  Publishing Ltd  in  1988,
+abbreviated  as   I<B1R>.  For  the   ISBN,  I  am  puzzled.   On  the
+administrative page at  the beginning of the book, there  is a sticker
+with number 1 85310 033 1 and on  the flap of the book cover, the ISBN
+is 1 85310 032 3. Take your pick.
+
+=item *
+
+I<Air Warfare in the Missile Age> by Lon O. Nordeen, Jr., published by
+the Smithsonian  Institution in 1985  and by  Air and Armour  Press in
+1985, ISBN 0-85368-751-X, abbreviated as I<AWMA>.
+
 =back
 
 =head1 SOVIET EQUIPMENT
@@ -331,6 +376,10 @@ Battlefield surveillance radar, PL 97.
 
 Early warning radar, FDC 758.
 
+=item Big Nose
+
+Radar on Tu-28P, IEAA 157.
+
 =item Big Screen
 
 Early warning radar, FDC 759.
@@ -349,11 +398,7 @@ Target tracking radar, FDC 759.
 
 =item Dog Ear
 
-2S6 and Gaskin fire control radar, PL 104, 116.
-
-=item Dog Ear
-
-Warning and acquisition radar, PL 122.
+2S6 and SA-9 Gaskin warning and acquisition radar, PL 104, 116, 122.
 
 =item Don Kay
 
@@ -377,15 +422,15 @@ Target tracking radar, FDC 759.
 
 =item Fan Song
 
-Guidance radar for SA-2 missiles, mentioned in RT.
+Guidance radar for SA-2 missiles, mentioned in RT and AWMA.
 
 =item Fire Dome
 
-Gadfly fire control radar, PL 114.
+SA-11 Gadfly fire control radar, PL 114.
 
 =item Flap Lid
 
-Grumble fire control radar, PL 115.
+SA-10 Grumble fire control radar, PL 115.
 
 =item Flat Face
 
@@ -393,7 +438,7 @@ Warning and acquisition radar, PL 123.
 
 =item Fox Fire
 
-Radar on MiG-25, DF. Mentionned in RSR.
+Radar on MiG-25, DF, IEAA 157, 158. Mentionned in RSR.
 
 =item Front Dome
 
@@ -409,7 +454,7 @@ Submarine mounted radar, FDC 759.
 
 =item Gun Dish
 
-ZSU-23-4 fire control radar, PL 105, mentioned in RT.
+ZSU-23-4 fire control radar, PL 105, mentioned in RT and AWMA.
 
 =item Half Cup
 
@@ -433,7 +478,7 @@ Radar on MiG-21F and Su-17/22, ASu, DF.
 
 =item High Lark
 
-Radar on MiG-23M and MiG-23MF, ASu, DF. Mentioned in RSR.
+Radar on MiG-23M and MiG-23MF, ASu, DF, IEAA 159. Mentioned in RSR.
 
 =item High Sieve
 
@@ -445,7 +490,7 @@ Surveillance, acquisition and tracking radar, PL 104.
 
 =item Jay Bird
 
-Radar on MiG-21MF and MiG-21bis, ASu.
+Radar on MiG-21MF and MiG-21bis, ASu and AWMA.
 
 =item Kite Screech
 
@@ -453,11 +498,15 @@ Gun control radar, FDC 759.
 
 =item Land Roll
 
-Gopher and Gecko fire control radar, PL 113, 117.
+SA-13 Gopher and SA-8 Gecko fire control radar, PL 113, 117.
 
 =item Long Track
 
-Gainful and Ganef warning and acquisition radar, PL 118, 119, 121.
+SA-6 Gainful and SA-4 Ganef warning and acquisition radar, PL 118, 119, 121.
+
+=item Low Blow
+
+Radar used by SA-3 Goa, mentioned in AWMA.
 
 =item Muff Cob
 
@@ -473,7 +522,7 @@ Naigation radar, FDC 758.
 
 =item Pat Hand
 
-Ganef warning and acquisition radar, PL 119.
+SA-4 Ganef acquisition and tracking radar, PL 119.
 
 =item Peel Cone
 
@@ -519,6 +568,10 @@ Ranging radar on MiG-15P and MiG-17P, DF.
 
 Radar on MiG-19P, DF.
 
+=item Scan Three
+
+Radar on Yak-25, IEAA 157.
+
 =item Scoop Pair
 
 Target tracking radar, FDC 759.
@@ -529,7 +582,8 @@ Aircraft altitude acquisition radar, PL 124.
 
 =item Skip Spin
 
-Radar on Su-15, ASu, DF.
+Radar on  Su-15, ASu, DF, and  on Yak-28P and Su-11  according to IEAA
+157.
 
 =item Sky Watch
 
@@ -565,7 +619,7 @@ Submarine mounted radar, FDC 759.
 
 =item Spin Scan
 
-Radar on MiG-21MF, ASu.
+Radar on MiG-21MF, ASu and AWMA.
 
 =item Spin Trough
 
@@ -581,7 +635,7 @@ Early warning and target designation radar, FDC 759.
 
 =item Straight Flush
 
-Gainful surveillance and tracking radar, PL 118, 120.
+SA-6 Gainful surveillance and tracking radar, PL 118, 120, B1R 134, AWMA.
 
 =item Strut Curve
 
@@ -601,7 +655,7 @@ Radar mounted on some variants of the BRM reco vehicle, PL 11.
 
 =item Thin Skin
 
-Gainful aircraft altitude acquisition radar, PL 118, 121.
+SA-6 Gainful aircraft altitude acquisition radar, PL 118, 121.
 
 =item Top Dome
 
@@ -915,8 +969,8 @@ Nuclear-powered attack submarine (SSN), FDC 793. Mentioned in HTMW 224 as Echo I
 
 =item Echo II
 
-Nuclear-powered aerodynamic missile submarine (SSGN), FDC 786
-or nuclear-powered auxiliary / rescue submarine (SSAN), FDC 797.
+Nuclear-powered  aerodynamic  missile  submarine (SSGN),  FDC  786  or
+nuclear-powered auxiliary / rescue submarine (SSAN), FDC 797.
 
 =item Echo II Mod
 
@@ -1065,13 +1119,14 @@ Yak aircraft, number unknown, AWA 392.
 
 =item Backfire
 
-Tu-22M / Tu-26  variable geometry bomber, JWARH 37,  189, FDC 775, AWA
-392, SPIAW, HTMW 165+267+436.  A very prominent character in RSR.
+Tu-22M / Tu-26  variable geometry bomber, JWARH 37, 189,  FDC 775, AWA
+392, SPIAW,  HTMW 165+267+436, S&V 92,  IEAA 47, 92, 109,  110, 111. A
+very prominent character in RSR.
 
 =item Badger
 
-Tu-16  bomber,  JWARH  37,  93,  LFDC  368, FDC  774,  AWA  392,  HTMW
-165+267+436.  A prominent character in RSR.
+Tu-16  bomber,  JWARH  37,  93,  LFDC 368,  FDC  774,  AWA  392,  HTMW
+165+267+436, AWMA, IEAA 36, 96, 110. A prominent character in RSR.
 
 =item Bank
 
@@ -1087,12 +1142,13 @@ Tu-2, AWA 392.
 
 =item Beagle
 
-Il-28 bomber, JWARH 37, 216, LFDC 368, AWA 392.
+Il-28 bomber, JWARH 37, 216, LFDC 368, AWA 392, IEAA 36, 140.
 
 =item Bear
 
 Tu-95 bomber or Tu-142 bomber (Bear F and H), JWARH 37, 121, LFDC 368,
-FDC 774, AWA 392, HTMW 165+436.  A prominent character in RSR.
+FDC  774, AWA  392,  HTMW 165+436,  IEAA 109,  111,  140. A  prominent
+character in RSR.
 
 =item Beast
 
@@ -1100,15 +1156,16 @@ Il-10, AWA 392.
 
 =item Bison
 
-M-4 bomber, JWARH 37, 94, AWA 392, HTMW 436.
+M-4 bomber, JWARH 37, 94, AWA 392, HTMW 436, IEAA 183.
 
 =item Blackjack
 
-Tu supersonic bomber, JWARH 37, AWA 392, HTMW 165+436.
+Tu supersonic bomber, JWARH 37, AWA 392, HTMW 165+436, IEAA 111.
 
 =item Blinder
 
-Tu-22 bomber, JWARH 37, 132, LFDC 368, FDC 774, AWA 392, HTMW 165+436. Mentioned in RSR.
+Tu-22 bomber, JWARH 37, 132, LFDC 368, FDC 774, AWA 392, HTMW 165+436,
+S&V 91, IEAA 47, 109, 157, B1R 31. Mentioned in RSR.
 
 =item Blowlamp
 
@@ -1176,7 +1233,7 @@ Il-76 transport aircraft, PL 218, JWARH 37, 118, AWA 392. Mentioned in RSR.
 
 =item Careless
 
-Tu-154 transport aircraft, JWARH 37, 134, AWA 392.
+Tu-154 transport aircraft, JWARH 37, 134, AWA 392, S&V 51.
 
 =item Cash
 
@@ -1192,7 +1249,7 @@ An-10 transport aircraft, JWARH 37, AWA 392.
 
 =item Charger
 
-Tu-144 supersonic airliner, JWARH 37.
+Tu-144 supersonic airliner, JWARH 37, S&V 50.
 
 =item Clam
 
@@ -1204,7 +1261,7 @@ An-30 transport aircraft, JWARH 37, 28, AWA 392.
 
 =item Classic
 
-Il-62 airliner, JWARH 37, 138, AWA 392.
+Il-62 airliner, JWARH 37, 138, AWA 392, S&V 49.
 
 =item Cleat
 
@@ -1244,7 +1301,8 @@ An-24 transport aircraft, JWARH 37, 286, AWA 392.
 
 =item Colt
 
-An-2 WW-2 vintage biplane transport aircraft, JWARH 37, 469, AWA 392.
+An-2 WW-2 vintage biplane transport  aircraft, JWARH 37, 469, AWA 392,
+AWMA.
 
 =item Condor
 
@@ -1280,7 +1338,7 @@ Yak-10, AWA 392.
 
 =item Crusty
 
-Tu-134 transport aircraft, JWARH 38, 133, AWA 392.
+Tu-134 transport aircraft, JWARH 38, 133, AWA 392, S&V 50.
 
 =item Cub
 
@@ -1296,7 +1354,7 @@ An-26 transport aircraft, PL 220, JWARH 38, 286, AWA 392.
 
 =item Fagot
 
-MiG-15bis, JWARH 38, DF, AWA 392, SPIAW.
+MiG-15bis, JWARH 38, DF, AWA 392, SPIAW, AWMA.
 
 =item Fang
 
@@ -1312,7 +1370,7 @@ MiG-9 fighter, AWA 392.
 
 =item Farmer
 
-MiG-19 fighter, PL 213, JWARH 38, 56, DF, AWA 392, SPIAW.
+MiG-19 fighter, PL 213, JWARH 38, 56, DF, AWA 392, SPIAW, AWMA.
 
 =item Feather
 
@@ -1321,11 +1379,12 @@ Yak-17 fighter, AWA 392.
 =item Fencer
 
 Su-24 variable  geometry strike fighter,  PL 211, JWARH 38,  187, ASt,
-AWA 392, HTMW 165. Or Su-19 according to SPIAW.
+AWA 392, HTMW 165, AWMA, IEAA 111. Or Su-19 according to SPIAW and S&V
+92.
 
 =item Fiddler
 
-Tu-28 and Tu-118 fighters, PL 223, JWARH 38, 75, AWA 392.
+Tu-28 and Tu-118 fighters, PL 223, JWARH 38, 75, AWA 392, IEAA 157.
 
 =item Fin
 
@@ -1337,7 +1396,8 @@ Yak-28 fighter, PL 222, JWARH 38, 98, AWA 392.
 
 =item Fishbed
 
-MiG-21 fighter, PL 211, JWARH 38, 177, ASu, DF, AWA 392, SPIAW, HTMW 165.
+MiG-21 fighter, PL  211, JWARH 38, 177, ASu, DF,  AWA 392, SPIAW, HTMW
+165, S&V 91, AWMA.
 
 =item Fishpot
 
@@ -1346,16 +1406,18 @@ Su-9/Su-11 fighter, PL 222, JWARH 38, 176, AWA 392.
 =item Fitter
 
 Su-7  fighter  (Fitter A)  or  Su-17/20/22  variable geometry  fighter
-(Fitter C  and D) or Su-17 fighter  (Fitter K), PL 212,  JWARH 38, 57,
-186, ASu, FDC 775, AWA 392, SPIAW, HTMW 165.
+(Fitter C, D and H) or Su-17 fighter (Fitter K), PL 212, JWARH 38, 57,
+186, ASu, FDC 775, AWA 392, SPIAW, HTMW 165, B1R 31, AWMA, IEAA 156.
 
 =item Flagon
 
-Su-21 fighter aircraft, PL 222. Or Su-15 fighter, JWARH 38, 175, ASu, DF, AWA 392, SPIAW, HTMW 165.
+Su-21 fighter aircraft, PL 222, IEAA  157. Or Su-15 fighter, JWARH 38,
+175, ASu, DF, AWA 392, SPIAW, HTMW 165, S&V 92.
 
 =item Flanker
 
-Su-27 fighter, PL 208, JWARH 38, 88, ASu, AWA 392, HTMW 165. Mentioned in RSR.
+Su-27 fighter, PL 208, JWARH 38, 88, ASu, AWA 392, HTMW 165, IEAA 160.
+Mentioned in RSR.
 
 =item Flashlight
 
@@ -1365,7 +1427,8 @@ Yak-25 and Yak-27 fighters, AWA 392.
 
 MiG-23 variable geometry fighter (Flogger  A and G) or MiG-27 variable
 geometry fighter (Flogger  D and J), PL 210, JWARH  38, 184, 185, ASu,
-ASt, DF, AWA 392, SPIAW, HTMW 165.  Mentioned in RSR.
+ASt, DF,  AWA 392, SPIAW,  HTMW 165, S&V 92,  B1R 31, 130,  AWMA, IEAA
+156, 158. Mentioned in RSR.
 
 =item Flora
 
@@ -1373,15 +1436,18 @@ Yak-23 fighter, AWA 392.
 
 =item Forger
 
-Yak-38 VSTOL fighter, PL 214, JWARH 38, 64, FDC 775, AWA 392, HTMW 165. Mentioned in THFRO.
+Yak-38 VSTOL  fighter, PL 214,  JWARH 38, 64,  FDC 775, AWA  392, HTMW
+165, S&V 156, IEAA 111, 159. Mentioned in THFRO.
 
 =item Foxbat
 
-MiG-25 interceptor, PL 223, 224, JWARH 38, 85, DF, AWA 392, SPIAW, HTMW 165. Mentioned in RSR.
+MiG-25 interceptor,  PL 223, 224,  JWARH 38,  85, DF, AWA  392, SPIAW,
+HTMW 165, S&V 91, AWMA, IEAA 157, 158. Mentioned in RSR.
 
 =item Foxhound
 
-MiG-31 interceptor, PL 224, JWARH 38, 86, ASu, AWA 392, HTMW 165.
+MiG-31 interceptor, PL 224, JWARH 38, 86, ASu, AWA 392, HTMW 165, IEAA
+160.
 
 =item Frank
 
@@ -1393,7 +1459,7 @@ Lend-lease P-63 fighter, AWA 392.
 
 =item Fresco
 
-MiG-17 fighter, PL 213, JWARH 38, 55, DF, AWA 392, SPIAW.
+MiG-17 fighter, PL 213, JWARH 38, 55, DF, AWA 392, SPIAW, AWMA.
 
 =item Fritz
 
@@ -1401,11 +1467,13 @@ La-9 fighter, AWA 392.
 
 =item Frogfoot
 
-Su-25 attack aircraft, PL 209, JWARH 38, 212, ASt, AWA 392, HTMW 165.
+Su-25 attack aircraft, PL 209, JWARH  38, 212, ASt, AWA 392, HTMW 165,
+IEAA 134.
 
 =item Fulcrum
 
-MiG-29 fighter, PL 208, JWARH 38, 87, ASu, AWA 392, HTMW 165. Mentioned in RSR.
+MiG-29 fighter,  PL 208, JWARH  38, 87, ASu,  AWA 392, HTMW  165, IEAA
+159. Mentioned in RSR.
 
 =item Madge
 
@@ -1429,8 +1497,8 @@ Su-11U variant of Fishpot, JWARH 38, AWA 392.
 
 =item Mail
 
-Be-12  amphibian aircraft,  JWARH  39,  460, FDC  775,  AWA 392,  HTMW
-267. AWA 392 gives also the M-12 designation.
+Be-12 amphibian aircraft,  JWARH 39, 460, FDC 775, AWA  392, HTMW 267.
+IEAA 140 and AWA 392 give also the M-12 designation.
 
 =item Mainstay
 
@@ -1466,7 +1534,8 @@ Yak-18 trainer, JWARH 39, 360, AWA 392.
 
 =item May
 
-Il-38 maritime reconnaissance aircraft, JWARH 39, 316, FDC 775, AWA 392, HTMW 267. Mentioned in RSR.
+Il-38 maritime  reconnaissance aircraft, JWARH  39, 316, FDC  775, AWA
+392, HTMW 267, IEAA 140. Mentioned in RSR.
 
 =item Maya
 
@@ -1502,7 +1571,8 @@ Lend-lease PBY Catalina, AWA 392.
 
 =item Moss
 
-Tu-126 airborne early warning aircraft, JWARH 39, 122, AWA 392, HTMW 267.
+Tu-126 airborne early  warning aircraft, JWARH 39, 122,  AWA 392, HTMW
+267, AWMA.
 
 =item Mote
 
@@ -1542,7 +1612,7 @@ Mi-1 / Mi-3 light helicopter, JWARH 38, 509, AWA 392.
 
 =item Harke
 
-Mi-10 heavy transport helicopter, PL 202, JWARH 38, 539, AWA 392.
+Mi-10 heavy transport helicopter, PL 202, JWARH 38, 539, AWA 392, S&V 122.
 
 =item Harp
 
@@ -1550,16 +1620,18 @@ Ka-20 ASW helicopter, LFDC 368.
 
 =item Havoc
 
-Mi-28 attack helicopter, PL 198, JWARH 38, AWA 392, HTMW 163.
+Mi-28 attack helicopter, PL 198, JWARH 38, AWA 392, HTMW 163. Mentioned in HA.
 
 =item Haze
 
-Mi-14 naval helicopter, JWARH 38, 529, FDC 775, AWA 392, HTMW 267.
+Mi-14 naval  helicopter, JWARH 38,  529, FDC  775, AWA 392,  HTMW 267,
+IEAA 140.
 
 =item Helix
 
 Ka-27 or Ka-32 naval transport  and support medium helicopter, PL 201,
-JWARH 38, 542, FDC 775, AWA 392, HTMW 163+267. Mentioned in RSR.
+JWARH 38, 542, FDC 775, AWA  392, HTMW 163+267, IEAA 140. Mentioned in
+RSR.
 
 =item Hen
 
@@ -1567,12 +1639,14 @@ Ka-15 light helicopter, JWARH 38, AWA 392.
 
 =item Hind
 
-Mi-24 / Mi-25 attack and transport helicopter, PL 199, JWARH 38, 530, AWA 392, HTMW 165. Mentioned in RSR.
+Mi-24 / Mi-25 attack and transport  helicopter, PL 199, JWARH 38, 530,
+AWA 392, HTMW 165, IEAA 134, 161, 182, 183. Mentioned in RSR and HA.
 
 =item Hip
 
 Mi-8 or Mi-17  medium transport and support helicopter,  PL 203, JWARH
-38, 528, FDC 775, AWA 392, HTMW 165. Mentioned in RSR.
+38, 528, FDC 775,  AWA 392, HTMW 165, S&V 119,  IEAA 134. Mentioned in
+RSR.
 
 =item Hog
 
@@ -1580,27 +1654,30 @@ Ka-18 light helicopter, JWARH 38, AWA 392.
 
 =item Hokum
 
-Attack helicopter designed by Kamov, PL 198, JWARH 38, AWA 392.
+Attack helicopter designed  by Kamov, PL 198, JWARH 38,  AWA 392, IEAA
+161. Mentioned in HA.
 
 =item Homer
 
-Mi-12, AWA 392.
+Mi-12, AWA 392, S&V 122.
 
 =item Hoodlum
 
-Ka-26 light transport helicopter, PL 200, JWARH 38, 543, AWA 392.
+Ka-26 light transport helicopter, PL 200, JWARH 38, 543, AWA 392, S&V 118.
 
 =item Hook
 
-Mi-6 heavy transport helicopter, PL 202, JWARH 38, 537, AWA 392, HTMW 165.
+Mi-6 heavy transport helicopter, PL 202, JWARH 38, 537, AWA 392, HTMW 165, S&V 119.
 
 =item Hoplite
 
-Mi-2  light transport and support helicopter, PL 204, JWARH 38, 513, AWA 392.
+Mi-2 light  transport and support  helicopter, PL 204, JWARH  38, 513,
+AWA 392, IEAA 134.
 
 =item Hormone
 
-Ka-25 naval helicopter, JWARH 38, 541, FDC 775, AWA 392, HTMW 163+267.
+Ka-25 naval helicopter, JWARH 38, 541, FDC 775, AWA 392, HTMW 163+267,
+IEAA 140.
 
 =item Horse
 
@@ -1625,47 +1702,54 @@ the same.
 
 =item Acrid
 
-AA-6 air-to-air missile, PL 223, JWARH 30, DF, SPIAW, HTMW 174.
+AA-6 air-to-air missile, PL 223, JWARH  30, DF, SPIAW, HTMW 174, AWMA,
+IEAA 158.
 
 =item Alamo
 
-AA-10 air-to-air missile, PL 225, ASu, DF, HTMW 174.
+AA-10 air-to-air missile, PL 225, ASu, DF, HTMW 174, IEAA 160.
 
 =item Alkali
 
-AA-1 air-to-air missile, PL 213, SPIAW.
+AA-1 air-to-air missile, PL 213, SPIAW, AWMA.
 
 =item Amos
 
-AA-9 air-to-air missile, PL 224, ASu, HTMW 174.
+AA-9 air-to-air missile, PL 224, ASu, HTMW 174, IEAA 158, 160.
 
 =item Anab
 
-AA-3 air-to-air missile, PL 222, JWARH 29, ASu, SPIAW, HTMW 174.
+AA-3 air-to-air  missile (soviet designation would  be RP-11 according
+to IEAA), PL 222, JWARH 29, ASu, SPIAW, HTMW 174, IEAA 157, 160, 161.
 
 =item Apex
 
-AA-7 air-to-air missile, PL 208, 210, 211, 224, JWARH 29, ASu, SPIAW, HTMW 174.
+AA-7 air-to-air  missile (or  R-23T and R-23R  according to  IEAA), PL
+208, 210,  211, 224, JWARH 29,  ASu, SPIAW, HTMW 174,  AWMA, IEAA 158,
+160.
 
 =item Aphid
 
-AA-8 air-to-air missile, PL 208, 210, 211, 214, 224, JWARH 29, ASu, SPIAW, HTMW 174.
+AA-8 air-to-air missile (or R-60 according to IEAA), PL 208, 210, 211,
+214, 224, JWARH 29, ASu, SPIAW, HTMW 174, AWMA, IEAA 156, 159, 161.
 
 =item Archer
 
-AA-11 air-to-air missile, PL 225.
+AA-11 air-to-air missile, PL 225, IEAA 161.
 
 =item Ash
 
-AA-5 air-to-air missile, PL 223, JWARH 29, DF.
+AA-5 air-to-air missile, PL 223, JWARH 29, DF, IEAA 157, 158.
 
 =item Atoll
 
-AA-2 air-to-air missile, PL 210, 213, 222, JWARH 30, DF, SPIAW, HTMW 174. Mentioned in RT, F2 and THFRO.
+AA-2 air-to-air  missile (K-13A or  SB-06 according to IEAA),  PL 210,
+213, 222,  JWARH 30, DF,  SPIAW, HTMW 174,  AWMA, IEAA 156,  159, 161.
+Mentioned in RT, F2 and THFRO.
 
 =item Frog
 
-PL 96.
+Backcronym for "Free Rocket Over Ground", PL 96, AWMA.
 
 =item Gadfly
 
@@ -1673,7 +1757,7 @@ SA-11 / SA-N-7 anti-aircraft missile, PL 114, FDC 755.
 
 =item Gainful
 
-SA-6 ground-to-air missile, PL 118, SPIAW.
+SA-6 ground-to-air missile, PL 118, SPIAW, B1R 133, AWMA.
 
 =item Ganef
 
@@ -1685,7 +1769,7 @@ SA-9 ground-to-air missile, PL 116.
 
 =item Gecko
 
-SA-8 / SA-N-4 anti-aircraft missile, PL 117, FDC 755.
+SA-8 / SA-N-4 anti-aircraft missile, PL 117, FDC 755, AWMA.
 
 =item Gladiator
 
@@ -1693,7 +1777,7 @@ SA-12 ground-to-air missile, PL 114.
 
 =item Goa
 
-SA-N-1 anti-aircraft missile, LFDC 367, FDC 755, SPIAW.
+SA-3 / SA-N-1 anti-aircraft missile, LFDC 367, FDC 755, SPIAW, AWMA.
 
 =item Goblet
 
@@ -1705,7 +1789,8 @@ SA-13 ground-to-air missile, PL 113.
 
 =item Grail
 
-SA-7 / SA-N-5 anti-aircraft missile, FDC 755, SPIAW. RT gives a Russian name, I<Strela>.
+SA-7 / SA-N-5  anti-aircraft missile, FDC 755, SPIAW,  AWMA, IEAA 161.
+RT gives a Russian name, I<Strela>.
 
 =item Gremlin
 
@@ -1717,25 +1802,30 @@ SA-10 / SA-N-6 anti-aircraft missile, PL 115, FDC 755.
 
 =item Guideline
 
-SA-2 / SNA-1 anti-aircraft missile, LFDC 367, SPIAW.
+SA-2 / SNA-1 anti-aircraft missile, LFDC 367, SPIAW, AWMA.
 
 =item Kangaroo
 
-AS-3 air-to-ground missile, HTMW 175.
-Note: JWARH 25 gives the name "Kangroo" (surely a typo for kangaroo),
-and LFDC 367 gives the name with a French spelling: "Kangourou".
+AS-3 air-to-ground missile,  HTMW 175, IEAA 109. Note:  JWARH 25 gives
+the name  "Kangroo" (surely a typo  for kangaroo), and LFDC  367 gives
+the name with a French spelling: "Kangourou".
 
 =item Karen
 
-AS-10 air-to-ground missile, PL 211, 226, FDC 756.
+AS-10 air-to-ground missile, PL 211, 226, FDC 756, IEAA 111.
 
 =item Kedge
 
-AS-14 air-to-ground missile, PL 211, 226.
+AS-14 air-to-ground missile, PL 211, 226, IEAA 111.
+
+=item Kegler
+
+Very brief entry in IEAA 111.
 
 =item Kelt
 
-AS-5 air-to-ground missile, JWARH 25, FDC 756, HTMW 174. Mentioned in RSR.
+AS-5 air-to-ground  missile, JWARH 25,  FDC 756, HTMW 174,  AWMA, IEAA
+96, 110. Mentioned in RSR.
 
 =item Kennel
 
@@ -1743,23 +1833,26 @@ AS-1 air-to-surface missile, LFDC 367.
 
 =item Kent
 
-AS-15 air-to-ground missile, FDC 756.
+AS-15 air-to-ground missile, FDC 756, IEAA 111.
 
 =item Kerry
 
-AS-7 air-to-ground missile, PL 209, 212, 214, 226, JWARH 27, FDC 756, HTMW 175.
+AS-7 air-to-ground missile, PL 209, 212,  214, 226, JWARH 27, FDC 756,
+HTMW 175, IEAA 48, 110.
 
 =item Kingfish
 
-AS-6 air-to-ground missile, FDC 756, HTMW 174, named Kingfisher by JWARH 25. Mentioned in RSR.
+AS-6  air-to-ground  missile,  FDC  756, HTMW  174,  IEAA  110,  named
+Kingfisher by JWARH 25. Mentioned in RSR.
 
 =item Kipper
 
-AS-2 air-to-ground missile, JWARH 25, LFDC 367, FDC 756, HTMW 175.
+AS-2 air-to-ground  missile, JWARH  25, LFDC 367,  FDC 756,  HTMW 175,
+IEAA 109.
 
 =item Kitchen
 
-AS-4 air-to-ground missile, LFDC 367, FDC 756, HTMW 175.
+AS-4 air-to-ground missile, LFDC 367, FDC 756, HTMW 175, IEAA 109.
 
 =item Kyle
 
@@ -1767,7 +1860,9 @@ AS-9 air-to-ground missile, FDC 756.
 
 =item Sagger
 
-AT-3 Antiarmour missile mounted on BMP-1, BMD-1, BVP-80A, OT-64C, BRDM-2, BRDM, PL 37, 38, 40, 49, 57, 59, 60, 227, HTMW 90.
+AT-3  Antiarmour missile  mounted  on BMP-1,  BMD-1, BVP-80A,  OT-64C,
+BRDM-2 and BRDM. The Russian name is I<Malyutka> according to IEAA. PL
+37, 38, 40, 49, 57, 59, 60, 227, HTMW 90, AWMA, IEAA 133, 134.
 
 =item Sampson
 
@@ -1795,7 +1890,7 @@ SS-NX-24 cruise missile, FDC 755.
 
 =item Scud
 
-SS1-C, PL 96.
+SS1-C, PL 96, AWMA.
 
 =item Serb
 
@@ -1847,7 +1942,8 @@ AT-4 antiarmour missile mounted on BMP-1, BMD-1, BMD-2, BMP-30, PL 37, 38, 41, 4
 
 =item Spiral
 
-AT-3 antiarmour missile, PL 227, HTMW 90.
+AT-6 antiarmour missile,  PL 227, HTMW 90, IEAA 111,  134 (which gives
+both the code AT-6 and the alternate code AS-8).
 
 =item Stallion
 
@@ -1871,7 +1967,7 @@ SS-N-20 ballistic missile, FDC 754. THFRO gives it the name "Seahawk".
 
 =item Styx
 
-SS-N-2 anti-ship missile, LFDC 367, FDC 754.
+SS-N-2 anti-ship missile, LFDC 367, FDC 754, AWMA, IEAA 96, 110.
 
 =item Sunburn
 
@@ -1879,7 +1975,7 @@ SS-N-22 anti-ship missile, FDC 755.
 
 =item Swatter
 
-AT-2 antiarmour missile, PL 227.
+AT-2 antiarmour missile, PL 227, IEAA 134.
 
 =back
 
@@ -1892,7 +1988,8 @@ are, for the sake of completeness.
 
 =item Faceplate
 
-MiG-21 fighter, AWA 392.
+MiG-21  fighter,  AWA  392.  Mentioned  in  IEAA  109  as  "the  Ye-2A
+'Faceplate' by the Mikoyan bureau".
 
 =item Flipper
 
@@ -1908,12 +2005,19 @@ L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::MultiList>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests to
-C<bug-acme-metasyntactic-soviet at rt.cpan.org>,
-or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Acme-MetaSyntactic-soviet>.
-I will be notified, and then you'll automatically be notified of
-progress on your bug as I make changes.
+Please   report  any   bugs   or  feature   requests   to  Github   at
+C<https://github.com/jforget/Acme-MetaSyntactic-soviet/issues>,    and
+create an issue or submit a pull request.
+
+If you have no  feedback after a week or so, try to  reach me by email
+at JFORGET  at cpan  dot org.  The notification  from Github  may have
+failed to reach  me. In your message, please  mention the distribution
+name in the subject, so my spam filter and me will easily dispatch the
+email to the proper folder.
+
+On the other hand, I may be on vacation. Do not be upset if the answer
+arrives after one or  two months. Be upset only if  you do not receive
+an answer to several emails over at least six months or one year.
 
 =head1 SUPPORT
 
@@ -1925,22 +2029,6 @@ You can also look for information at:
 
 =over 4
 
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Acme-MetaSyntactic-soviet>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Acme-MetaSyntactic-soviet>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Acme-MetaSyntactic-soviet>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Acme-MetaSyntactic-soviet>
-
 =item * MetaCPAN
 
 L<https://metacpan.org/pod/Acme::MetaSyntactic::soviet>
@@ -1955,15 +2043,15 @@ L<https://github.com/jforget/Acme-MetaSyntactic-soviet>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright  2008, 2012, 2016  Jean Forget,  all rights  reserved.  This
-program is  free software;  you can redistribute  it and/or  modify it
-under the same  terms as Perl itself: GNU Public  License version 1 or
-later and Perl Artistic License.
+Copyright 2008,  2012, 2016,  2021 Jean  Forget, all  rights reserved.
+This program is  free software; you can redistribute  it and/or modify
+it under the  same terms as Perl itself: GNU  Public License version 1
+or later and Perl Artistic License.
 
 The full text of the license can be found in the F<LICENSE> file included
 with this module or at
-L<http://www.perlfoundation.org/artistic_license_1_0> and
-L<http://www.gnu.org/licenses/gpl-1.0.html>.
+L<https://dev.perl.org/licenses/artistic.html>
+and L<https://www.gnu.org/licenses/gpl-1.0.html>.
 
 Here is the summary of GPL:
 
@@ -1977,11 +2065,13 @@ WITHOUT   ANY  WARRANTY;   without  even   the  implied   warranty  of
 MERCHANTABILITY  or FITNESS  FOR A  PARTICULAR PURPOSE.   See  the GNU
 General Public License for more details.
 
-You  should have received  a copy  of the  GNU General  Public License
-along with this program; if not, see <http://www.gnu.org/licenses/> or
-write to the Free  Software Foundation, Inc., L<http://fsf.org>.  This
-program is free  software; you can redistribute it  and you can modify
-it under the same terms as Perl itself.
+You should  have received  a copy  of the  GNU General  Public License
+along with this program; if not, see
+L<https://www.gnu.org/licenses/gpl-1.0.html>   or  contact   the  Free
+Software Foundation, Inc., L<https://www.fsf.org/>.
+
+This program  is free software;  you can  redistribute it and  you can
+modify it under the same terms as Perl itself.
 
 =cut
 
